@@ -1,30 +1,37 @@
 package IO::All::STDIO;
-use IO::All -Base;
+use strict;
+use warnings;
+use IO::All -base;
 use IO::File;
 
 const type => 'stdio';
 
 sub stdio {
+    my $self = shift;
     bless $self, __PACKAGE__;
     return $self->_init;
 }
 
 sub stdin {
+    my $self = shift;
     $self->open('<');
     return $self;
 }
 
 sub stdout {
+    my $self = shift;
     $self->open('>');
     return $self;
 }
 
 sub stderr {
+    my $self = shift;
     $self->open_stderr;
     return $self;
 }
 
 sub open {
+    my $self = shift;
     $self->is_open(1);
     my $mode = shift || $self->mode || '<';
     my $fileno = $mode eq '>'
@@ -36,6 +43,7 @@ sub open {
 }
 
 sub open_stderr {
+    my $self = shift;
     $self->is_open(1);
     $self->io_handle(IO::File->new);
     $self->io_handle->fdopen(fileno(STDERR), '>') ? $self : 0;
@@ -43,8 +51,6 @@ sub open_stderr {
 
 # XXX Add overload support
 
-__DATA__
-
 =head1 NAME 
 
 IO::All::STDIO - STDIO Support for IO::All
@@ -69,3 +75,5 @@ under the same terms as Perl itself.
 See http://www.perl.com/perl/misc/Artistic.html
 
 =cut
+
+1;
